==> humhub-1.11.0-beta.2.tar.gz: humhub-1.11.0-beta.2/protected/humhub/modules/admin/messages/hu/modules.php <==
<?php

return [
    '%moduleName% - Set as default module' => '%moduleName% - Beállítás alapértelmezett modulként',
    '<strong>Module</strong> details' => '<strong>Modul</strong> részletek',
    'Activated' => 'Aktiválva',
    'Always activated' => 'Mindig aktiválva van',
    'Are you sure? *ALL* module data will be lost!' => 'Biztos vagy benne? *MINDEN* modul adat elvész!',
    'Are you sure? *ALL* module related data and files will be lost!' => 'Biztos vagy benne? *MINDEN* a modullal kapcsolatos és fájl elvész!',
    'Close' => 'Bezárás',
    'Configure' => 'Konfiguráció',
    'Could not find requested module!' => 'A kért modul nem található!',
    'Deactivated' => 'Deaktiválva',
    'Enable module...' => 'Modul bekapcsolása...',
    'Here you can choose whether or not a module should be automatically activated on a space or user profile. If the module should be activated, choose "always activated".' => 'Itt kiválaszthatod, hogy egy modul automatikusan aktiválódjon-e egy közösségben vagy felhasználói profilban. Ha azt szeretnéd, hogy a modul legyen aktiválva, válaszd a "mindig aktiválva" lehetőséget.',
    'License not found or expired. Please contact the module publisher.' => 'A licenc nem található vagy lejárt. Kérünk, lépj kapcsolatba a modul kiadójával.',
    'Module path %path% is not writeable!' => 'A(z ) %path% modulútvonal nem írható!',
    'Save' => 'Mentés',
    'Spaces' => 'Közösségek',
    'This module doesn\'t provide further information.' => 'Ez a modul nem nyújt további információkat.',
    'Activate' => '',
    'Deprecated' => '',
    'Featured' => '',
    'Installed' => '',
    'Module "{moduleName}" has been updated to version {newVersion} successfully.' => '',
    'New' => '',
    'No modules found.' => '',
    'Not Installed' => '',
    'Official' => '',
    'Partner' => '',
    'Professional Edition' => '',
    'Space default state' => '',
    'Try other keywords or remove filters.' => '',
    'Update successful' => '',
    'User default state' => '',
    'Users' => '',
];

==> humhub-1.15.0-beta.2.tar.gz: humhub-1.15.0-beta.2/protected/humhub/modules/admin/messages/hu/modules.php <==
<?php

return [
    '%moduleName% - Set as default module' => '%moduleName% - Beállítás alapértelmezett modulként',
    'Activated' => 'Aktiválva',
    'Always activated' => 'Mindig aktiválva van',
    'Are you sure? *ALL* module data will be lost!' => 'Biztos vagy benne? *MINDEN* modul adat elvész!',
    'Are you sure? *ALL* module related data and files will be lost!' => 'Biztos vagy benne? *MINDEN* a modullal kapcsolatos és fájl elvész!',
    'Close' => 'Bezárás',
    'Could not find requested module!' => 'A kért modul nem található!',
    'Deactivated' => 'Deaktiválva',
    'Deactivation of this module has not been completed yet. Please retry in a few minutes.' => 'Ennek a modulnak a deaktiválása még nem fejeződött be. Kérjük, próbálja újra néhány perc múlva.',
    'Enable module...' => 'Modul bekapcsolása...',
    'Here you can choose whether or not a module should be automatically activated on a space or user profile. If the module should be activated, choose "always activated".' => 'Itt kiválaszthatod, hogy egy modul automatikusan aktiválódjon-e egy közösségben vagy felhasználói profilban. Ha azt szeretnéd, hogy a modul legyen aktiválva, válaszd a "mindig aktiválva" lehetőséget.',
    'Module path %path% is not writeable!' => 'A(z ) %path% modulútvonal nem írható!',
    'Save' => 'Mentés',
    'Space default state' => 'Közösség alapértelmezett állapota',
    'Spaces' => 'Közösségek',
    'User default state' => 'Felhasználó alapértelmezett állapota',
    'Users' => 'Felhasználók',
    'Module deactivation in progress. This process may take a moment.' => '',
];
